Index: trunk/psLib/src/astronomy/psTime.h
===================================================================
--- trunk/psLib/src/astronomy/psTime.h	(revision 3706)
+++ trunk/psLib/src/astronomy/psTime.h	(revision 3708)
@@ -10,6 +10,6 @@
  *  @author Ross Harman, MHPCC
  *
- *  @version $Revision: 1.25 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-04-18 23:40:15 $
+ *  @version $Revision: 1.26 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2005-04-19 00:17:05 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -107,12 +107,12 @@
 );
 
 /** Convert psTime to Local Mean Sidereal Time (LST).
  *
  *  Converts psTime at the given longitude to LST time. If the input time is not in UTC format, then it is
  *  converted.
  *
  *  @return  double: LST Time.
  */
-double psTimeToLST(
+double psTimeToLMST(
     psTime *time,                       ///< psTime to be converted.
     double longitude                    ///< Longitude.
@@ -107,12 +107,12 @@
 );
 
-/** Convert psTime to Local Mean Sidereal Time (LST).
- *
- *  Converts psTime at the given longitude to LST time. If the input time is not in UTC format, then it is
+/** Convert psTime to Local Mean Sidereal Time (LMST).
+ *
+ *  Converts psTime at the given longitude to LMST time. If the input time is not in UTC format, then it is
  *  converted.
  *
